#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-7AeHJjVJuOa37VHakFnr8M
key:                  stack-2.9.3.1-7AeHJjVJuOa37VHakFnr8M
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  8e703d08bdb272ba1591d3e9b2c84854
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-7AeHJjVJuOa37VHakFnr8M
depends:
    Cabal-3.10.3.0 aeson-2.2.1.0-FEnGzvKMunxDwDFhBeJYHO
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-4Fc3pfbWuzJIdO3EFXFaIS array-0.5.6.0
    async-2.2.6-9S5YBpAZQ2fGtiHAvRKHi7
    attoparsec-0.14.4-L7yQnQokRKL4IK7J2HszTx base-4.18.2.1
    base64-bytestring-1.2.1.0-1NArAo3cNK0LoUlrXpNy9J
    bytestring-0.11.5.3 casa-client-0.0.3-BF7UFZwXSA8Ldz84GkLPY
    casa-types-0.0.3-IKmd66hLLre2TwqFeoe83t
    colour-2.3.7-KLOJ2cJWBRxK94LtnX527f
    conduit-1.3.6.1-7ztpQFzxkQu9fYslJzAtaH
    conduit-extra-1.3.8-EtHHdCy2JFLEIdUwh75e4q containers-0.6.7
    crypton-1.0.4-I0bzTn2woJ4DLB7BtNhDWv
    crypton-conduit-0.2.3-FLZcXJD1bNv6gJ3BXLdbSt deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-GBHSV2ca01pLlBBatrwGfL
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-6TS3FbRurIrK6N8uVg8x7G filepath-1.4.300.1
    fsnotify-0.4.4.0-H6sBzlx9luG2OBo2OFgJQn
    generic-deriving-1.14.7-5EVA7USioDvAPoGbgrXr77
    hackage-security-0.6.3.2-JuraGwicU4Q4F2skNkF1zH
    hashable-1.4.7.0-H7NkROSKCrjFQZGpvHIgO1
    hi-file-parser-0.1.8.0-5MLNMojbMuxGwgCLFVoYZn
    hpack-0.38.0-8htZFeWkozN66ZLEbEIICl hpc-0.6.2.0
    http-client-0.7.19-KIsPCwAmJfj40FXZ7rXqbo
    http-client-tls-0.3.6.4-Doual9R7PJYKTahqZ4qgD9
    http-conduit-2.3.9.1-9vgkevnzuZMGmzJ8MF8Wc0
    http-download-0.2.1.0-FmuLsIXssY60NmJZFcyM6
    http-types-0.12.4-5BZtRmLQcWTCOOFKM75zCu
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-3gXzBwStkP8DMhFPWv8vtv mtl-2.3.1
    mustache-2.4.3.1-8wDH3Fw0CWs7tZayVZ0liU
    neat-interpolation-0.5.1.4-8Ds5KcjcXwU4hguc0rEH5m
    network-uri-2.6.4.2-91j990LrivP71ivMfH7l0g
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-JYwGc1030kp1M9C8Y9ZIot
    pantry-0.8.3-FLMJ75VZspPFGRXZapXCrD
    path-0.9.6-IRE5PLEtTguLTbdZl0KbOt
    path-io-1.8.2-BW9d0e4Xzlu5wBy0j6qIO6
    persistent-2.14.5.2-DZ3717dPXzU6YMR2PWZWWn
    persistent-sqlite-2.13.2.0-7MKZmFOb6sPLkLRq5585T9 pretty-1.1.3.6
    primitive-0.9.1.0-CIlU66tAMro5ZKIlpCPDD4 process-1.6.19.0
    project-template-0.2.1.0-3a4zYRrmZwII8b3AqXIHZ9
    random-1.2.1.3-EZAJJDcAdrKCzLsP4iSxFh
    retry-0.9.3.1-8ew4mK8R73R5HIgqyODUvJ
    rio-0.1.24.0-E9Vj8Tqnt8kFAbCMmmpasN
    rio-prettyprint-0.1.8.0-AOrQgMfDHlYC7wdZXXNN8C
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    streaming-commons-0.2.3.1-Cl2UG7bTzrfFkrU6zusSBm
    tar-0.5.1.1-1xNVtM9J1aG9FTdaRySFYq template-haskell-2.20.0.0
    temporary-1.3-9rcNesEzN8L9Jsn9e228tO text-2.0.2
    text-metrics-0.3.3-2PYDnjDl0Gj9Dd2XOfPpio
    th-reify-many-0.1.10-HxferMy5Izt4ElKlkoEzqU time-1.12.2
    tls-2.0.6-HCqcWmvZgUh9ulRDq3xocc transformers-0.6.1.0
    typed-process-0.2.13.0-6u6wFfn6DMG9NJZ9BxYSzU
    unicode-transforms-0.4.0.1-KgvLtDPTRHv8i4b3MYqYTU unix-2.8.4.0
    unix-compat-0.7.4.1-CNHdcuBo4WyE8NnkOFSrdm
    unliftio-0.2.25.1-H2bxXnnkRB0DM3bojqNUxO
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V
    vector-0.13.2.0-BkeaBlIIAt9GprLstCadki
    yaml-0.11.11.2-2eCjVBmXmfmHZ8S9rFS2eL
    zip-archive-0.4.3.2-DEAU29gCy1yL8Hmh2HmXwp
    zlib-0.7.0.0-FKx1pZQIOYLfSmgbigs2H

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

